==> 0.1.3.zip: tourplaner/src/tourplaner/business/AlertHelper.java <==
package tourplaner.business;

import javafx.scene.control.Alert;
import javafx.scene.control.Label;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextInputDialog;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.Priority;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Optional;
import java.util.concurrent.atomic.AtomicReference;

public class AlertHelper {
    public static void warn(String title, String header, String msg){
        alertType(Alert.AlertType.WARNING, title, header, msg);
    }
    public static void inform(String title, String header, String msg){
        alertType(Alert.AlertType.INFORMATION, title, header, msg);
    }

    public static void informNoHeader(String title, String msg){
        inform(title, null, msg);
    }

    public static void error(String title, String header, String msg){
        alertType(Alert.AlertType.ERROR, title, header, msg);
    }

    public static void exerror(String title, String header, String msg, Exception ex){
        Alert alert = new Alert(Alert.AlertType.ERROR);
        alert.setTitle(title);
        alert.setHeaderText(header);
        alert.setContentText(msg);
        StringWriter sw = new StringWriter();
        PrintWriter pw = new PrintWriter(sw);
        ex.printStackTrace(pw);
        String exceptionText = sw.toString();
        Label label = new Label("Exception stacktrace:");
        TextArea textArea = new TextArea(exceptionText);
        textArea.setEditable(false);
        textArea.setWrapText(true);
        textArea.setMaxWidth(Double.MAX_VALUE);
        textArea.setMaxHeight(Double.MAX_VALUE);
        GridPane.setVgrow(textArea, Priority.ALWAYS);
        GridPane.setHgrow(textArea, Priority.ALWAYS);
        GridPane expContent = new GridPane();
        expContent.setMaxWidth(Double.MAX_VALUE);
        expContent.add(label, 0, 0);
        expContent.add(textArea, 0, 1);
        alert.getDialogPane().setExpandableContent(expContent);
        alert.showAndWait();
    }

    private static void alertType(Alert.AlertType alertly, String title, String header, String msg){
        Alert alert = new Alert(alertly);
        alert.setTitle(title);
        alert.setHeaderText(header);
        alert.setContentText(msg);

        alert.showAndWait();
    }

    public static String inputText(String title, String header, String msg) {
        TextInputDialog dialog = new TextInputDialog();
        dialog.setTitle(title);
        dialog.setHeaderText(header);
        dialog.setContentText(msg);
        Optional<String> result = dialog.showAndWait();
        AtomicReference<String> returnText = new AtomicReference<>("");
        result.ifPresent(returnText::set);
        if(!returnText.get().isEmpty()){
            return returnText.get();
        }else{
            return null;
        }
    }
}

==> 0.1.4.zip: tourplaner/src/tourplaner/business/AlertHelper.java <==
package tourplaner.business;

import javafx.scene.control.Alert;
import javafx.scene.control.Label;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextInputDialog;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.Priority;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Optional;
import java.util.concurrent.atomic.AtomicReference;

public class AlertHelper {
    public static void warn(String title, String header, String msg){
        alertType(Alert.AlertType.WARNING, title, header, msg);
    }
    public static void inform(String title, String header, String msg){
        alertType(Alert.AlertType.INFORMATION, title, header, msg);
    }

    public static void informNoHeader(String title, String msg){
        inform(title, null, msg);
    }

    public static void error(String title, String header, String msg){
        alertType(Alert.AlertType.ERROR, title, header, msg);
    }

    public static void exerror(String title, String header, String msg, Exception ex){
        Alert alert = new Alert(Alert.AlertType.ERROR);
        alert.setTitle(title);
        alert.setHeaderText(header);
        alert.setContentText(msg);
        StringWriter sw = new StringWriter();
        PrintWriter pw = new PrintWriter(sw);
        ex.printStackTrace(pw);
        String exceptionText = sw.toString();
        Label label = new Label(ConfigHelper.getIniString(ConfigHelper.getStandartConfig(), "langde", "exceptionstackheader"));
        TextArea textArea = new TextArea(exceptionText);
        textArea.setEditable(false);
        textArea.setWrapText(true);
        textArea.setMaxWidth(Double.MAX_VALUE);
        textArea.setMaxHeight(Double.MAX_VALUE);
        GridPane.setVgrow(textArea, Priority.ALWAYS);
        GridPane.setHgrow(textArea, Priority.ALWAYS);
        GridPane expContent = new GridPane();
        expContent.setMaxWidth(Double.MAX_VALUE);
        expContent.add(label, 0, 0);
        expContent.add(textArea, 0, 1);
        alert.getDialogPane().setExpandableContent(expContent);
        alert.showAndWait();
    }

    private static void alertType(Alert.AlertType alertly, String title, String header, String msg){
        Alert alert = new Alert(alertly);
        alert.setTitle(title);
        alert.setHeaderText(header);
        alert.setContentText(msg);

        alert.showAndWait();
    }

    public static String inputText(String title, String header, String msg) {
        TextInputDialog dialog = new TextInputDialog();
        dialog.setTitle(title);
        dialog.setHeaderText(header);
        dialog.setContentText(msg);
        Optional<String> result = dialog.showAndWait();
        AtomicReference<String> returnText = new AtomicReference<>("");
        result.ifPresent(returnText::set);
        if(!returnText.get().isEmpty()){
            return returnText.get();
        }else{
            return null;
        }
    }
}
